from django.urls import path

from service_catalog.api.views import *

urlpatterns = [
    # admin urls
    path('instance/', InstanceList.as_view(), name='api_instance_list'),
    path('instance/<int:pk>/', InstanceDetails.as_view(), name='api_instance_details'),
    path('instance/<int:pk>/spec/', SpecDetailsAPIView.as_view(), name='api_instance_spec_details'),
    path('instance/<int:pk>/user-spec/', UserSpecDetailsAPIView.as_view(), name='api_instance_user_spec_details'),
    path('instance/<int:instance_id>/operation/', InstanceOperationList.as_view(),
         name='api_instance_operation_list'),
    path('instance/<int:instance_id>/operation/<int:operation_id>/request/', OperationRequestCreate.as_view(),
         name='api_operation_request_create'),
    path('request/', RequestList.as_view(), name='api_request_list'),
    path('request/<int:pk>/', RequestDetails.as_view(), name='api_request_details'),
    path('request/<int:pk>/accept/', RequestStateMachine.as_view({'post': 'accept', 'get': 'get_survey'}),
         name='api_request_accept'),
    path('request/<int:pk>/reject/', RequestStateMachine.as_view({'post': 'reject'}),
         name='api_request_reject'),
    path('request/<int:pk>/process/', RequestStateMachine.as_view({'post': 'process'}),
         name='api_request_process'),
    path('request/<int:pk>/re-submit/', RequestStateMachine.as_view({'post': 're_submit'}),
         name='api_request_re_submit'),
    path('request/<int:pk>/archive', RequestStateMachine.as_view({'post': 'archive'}),
         name='api_request_archive'),
    path('request/<int:pk>/unarchive/', RequestStateMachine.as_view({'post': 'unarchive'}),
         name='api_request_unarchive'),
    path('request/<int:pk>/need-info/', RequestStateMachine.as_view({'post': 'need_info'}),
         name='api_request_need_info'),
    path('request/<int:pk>/cancel/', RequestStateMachine.as_view({'post': 'cancel'}),
         name='api_request_cancel'),
    path('service/', ServiceListCreate.as_view(), name='api_service_list_create'),
    path('service/<int:pk>/', ServiceDetails.as_view(), name='api_service_details'),
    path('service/<int:service_id>/operation/', OperationListCreate.as_view(), name='api_operation_list_create'),
    path('service/<int:service_id>/operation/<int:pk>/', OperationDetails.as_view(), name='api_operation_details'),
    path('service/<int:service_id>/operation/<int:pk>/survey/', OperationSurveyAPI.as_view(),
         name='api_operation_survey_list_update'),
    path('service/<int:pk>/request/', ServiceRequestCreate.as_view(), name='api_service_request_create'),
    path('tower/', TowerServerList.as_view(), name='api_tower_server_list_create'),
    path('tower/<int:pk>/', TowerServerDetails.as_view(), name='api_tower_server_details'),
    path('tower/<int:tower_server_id>/job_template/', JobTemplateList.as_view(),
         name='api_job_template_list'),
    path('tower/<int:tower_server_id>/job_template/sync/', JobTemplateSync.as_view(),
         name='api_job_template_sync_all'),
    path('tower/<int:tower_server_id>/job_template/<int:pk>/', JobTemplateDetails.as_view(),
         name='api_job_template_details'),
    path('tower/<int:tower_server_id>/job_template/<int:job_template_id>/sync/', JobTemplateSync.as_view(),
         name='api_job_template_sync'),
]
